"use strict";
// Copyright (c) Will Crichton
// Distributed under the terms of the Modified BSD License.
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const base_1 = require("@jupyter-widgets/base");
const version_1 = require("./version");
require("@wcrichto/vgrid/dist/vgrid.css");
const mobx_1 = require("mobx");
// Avoid "multiple mobx instances in application" issue
// https://mobx.js.org/refguide/api.html#-isolateglobalstate-boolean
mobx_1.configure({ isolateGlobalState: true });
const react_1 = __importDefault(require("react"));
const react_dom_1 = __importDefault(require("react-dom"));
const vgrid_1 = require("@wcrichto/vgrid");
// Use window.require so webpack doesn't try to import ahead of time
let Jupyter = window.require('base/js/namespace');
class VGridModel extends base_1.DOMWidgetModel {
    defaults() {
        return Object.assign({}, super.defaults(), { _model_name: VGridModel.model_name, _model_module: VGridModel.model_module, _model_module_version: VGridModel.model_module_version, _view_name: VGridModel.view_name, _view_module: VGridModel.view_module, _view_module_version: VGridModel.view_module_version });
    }
}
VGridModel.serializers = Object.assign({}, base_1.DOMWidgetModel.serializers);
VGridModel.model_name = 'VGridModel';
VGridModel.model_module = version_1.MODULE_NAME;
VGridModel.model_module_version = version_1.MODULE_VERSION;
VGridModel.view_name = 'VGridView'; // Set to null if no view
VGridModel.view_module = version_1.MODULE_NAME; // Set to null if no view
VGridModel.view_module_version = version_1.MODULE_VERSION;
exports.VGridModel = VGridModel;
class VGridContainer extends react_1.default.Component {
    constructor() {
        super(...arguments);
        this.state = {
            keyboardDisabled: false
        };
        this._timer = null;
        this._onClick = () => {
            let disabled = !this.state.keyboardDisabled;
            // wcrichto 5-25-18: in order to disable the Jupyter keyboard manager, we have to call disable
            // in an infinite loop. This is because the ipywidgets framework uses
            // KeyboardManager.register_events on the widget container which can cause unpredictable behavior
            // in unexpectedly reactivating the keyboard manager (hard to consistently maintain focus on the
            // widget area), so the simplest hacky solution is just to forcibly disable the manager by
            // overriding all other changes to its settings.
            if (disabled) {
                this._timer = setInterval(() => { Jupyter.keyboard_manager.disable(); }, 100);
            }
            else {
                clearInterval(this._timer);
                Jupyter.keyboard_manager.enable();
            }
            this.setState({ keyboardDisabled: disabled });
        };
    }
    componentWillUnmount() {
        if (this._timer != null) {
            clearInterval(this._timer);
        }
        Jupyter.keyboard_manager.enable();
    }
    render() {
        let JupyterButton = react_1.default.createElement("button", { onClick: this._onClick }, this.state.keyboardDisabled ? 'Enable Jupyter keyboard' : 'Disable Jupyter keyboard');
        return (react_1.default.createElement("div", { className: 'vgrid-container', onClick: (e) => { e.stopPropagation(); } },
            JupyterButton,
            react_1.default.createElement(vgrid_1.VGrid, Object.assign({}, this.props)),
            JupyterButton));
    }
}
class VGridView extends base_1.DOMWidgetView {
    constructor(params) {
        super(params);
        let { interval_blocks, database } = this.model.get('vgrid_json');
        this.database = vgrid_1.Database.from_json(database);
        this.interval_blocks = vgrid_1.interval_blocks_from_json(interval_blocks);
    }
    label_callback(label_state) {
        this.model.set('label_state', label_state.to_json());
        this.model.save_changes();
    }
    render() {
        react_dom_1.default.render(react_1.default.createElement(VGridContainer, { interval_blocks: this.interval_blocks, database: this.database, settings: this.model.get('settings'), label_callback: this.label_callback.bind(this) }), this.el);
    }
    remove() {
        if (!react_dom_1.default.unmountComponentAtNode(this.el)) {
            console.error('Failed to unmount VGrid');
        }
    }
}
exports.VGridView = VGridView;
//# sourceMappingURL=widget.js.map